<!---------------------- Introduction Section ------------------->
<h1> PTRAIL:  A <b><i>P</i></b>arallel 
<b><i>TR</i></b>ajectory 
d<b><i>A</i></b>ta
preprocess<b><i>I</i></b>ng
<b><i>L</i></b>ibrary

 </h1>

<h2> Introduction </h2>

<p align='justify'>
PTRAIL is a state-of-the art Mobility Data Preprocessing Library that mainly deals with filtering data, generating features and interpolation of Trajectory Data.

<b><i> The main features of PTRAIL are: </i></b>
</p>

<ol align='justify'>
<li> PTRAIL uses primarily parallel computation based on
     python Pandas and numpy which makes it very fast as compared
     to other libraries available.
</li>

<li> PTRAIL harnesses the full power of the machine that
     it is running on by using all the cores available in the
     computer.
</li>

<li> PTRAIL uses a customized DataFrame built on top of python
     pandas for representation and storage of Trajectory Data.
</li>

<li> PTRAIL also provides several Temporal and spatial features
     which are calculated mostly using parallel computation for very
     fast and accurate calculations.
</li>

<li> Moreover, PTRAIL also provides several filteration and
     outlier detection methods for cleaning and noise reduction of
     the Trajectory Data.
</li>

<li> Apart from the features mentioned above, <i><b> four </b></i>
     different kinds of Trajectory Interpolation techniques are
     offered by PTRAIL which is a first in the community.
</li>
</ol>

<!------------------------- Documentation Link ----------------->
<h2> Documentation </h2>

<span> &#8618; </span>
<a href='https://PTRAIL.readthedocs.io/en/latest/' target='_blank'> <i> PTRAIL Documentation </i> </a>

<!-------------------- Pip Installation ------------------------->
<h2> Pip Installation </h2>

1. `pip install PTRAIL`

<!------------------------ Usage Examples ----------------------->
<h2> Examples </h2>

<span> &#8618; </span>
<a href='https://github.com/YakshHaranwala/PTRAIL/tree/main/examples' target='_blank'> <i> PTRAIL Examples </i> </a>

<!--------------------- Binder Link ---------------------------->
<h2> Binder </h2>

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/YakshHaranwala/PTRAIL.git/HEAD)

<!-------------------- MISC ------------------------------------>
<h2> Miscellaneous </h2>

[![Downloads](https://static.pepy.tech/personalized-badge/ptrail?period=total&units=international_system&left_color=black&right_color=blue&left_text=Downloads)](https://pepy.tech/project/ptrail)

<!------------------- Citation ---------------------------------->
<h2> Citation </h2>

To cite PTRAIL in your academic work, please use the following citation: 

```bibtex
@article{haidri2021ptrail,
      title={PTRAIL -- A python package for parallel trajectory data preprocessing}, 
      author={Salman Haidri and Yaksh J. Haranwala and Vania Bogorny and Chiara Renso and Vinicius Prado da Fonseca and Amilcar Soares},
      year={2021},
      eprint={2108.13202},
      url={https://arxiv.org/abs/2108.13202},
      archivePrefix={arXiv},
      primaryClass={cs.DC}
}
```
